Struct plaid::institutions::GetInstitutionsOptions[][src]

pub struct GetInstitutionsOptions {
    pub products: Vec<String>,
    pub routing_numbers: Vec<String>,
    pub oauth: Option<bool>,
    pub include_optional_metadata: bool,
}

Fields

products: Vec<String>

Filter the Institutions based on which products they support. Possible values: assets, auth, balance, identity, investments, liabilities, payment_initiation, transactions, credit_details, income, deposit_switch

routing_numbers: Vec<String>

Specify an array of routing numbers to filter institutions.

oauth: Option<bool>

Limit results to institutions with or without OAuth login flows. This is primarily relevant to institutions with European country codes.

include_optional_metadata: bool

When true, return the institution's homepage URL, logo and primary brand color.