Struct plaid::institutions::GetInstitutionsResponse[][src]

pub struct GetInstitutionsResponse {
    pub request_id: String,
    pub institutions: Vec<Institution>,
    pub total: i32,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

institutions: Vec<Institution>

A list of Plaid Institution

total: i32

The number of institutions returned