Struct plaid::institutions::Institution[][src]

pub struct Institution {
    pub institution_id: String,
    pub name: String,
    pub products: Vec<String>,
    pub country_codes: Vec<String>,
    pub url: Option<String>,
    pub primary_color: Option<String>,
    pub logo: Option<String>,
    pub routing_numbers: Option<Vec<String>>,
    pub oauth: bool,
}

Fields

institution_id: String

Unique identifier for the institution

name: String

The official name of the institution

products: Vec<String>

A list of the Plaid products supported by the institution Possible values: assets, auth, balance, identity, investments, liabilities, payment_initiation, transactions, credit_details, income, deposit_switch

country_codes: Vec<String>

A list of the country codes supported by the institution. Possible values: US, GB, ES, NL, FR, IE, CA

url: Option<String>

The URL for the institution's website

primary_color: Option<String>

Hexadecimal representation of the primary color used by the institution

Base64 encoded representation of the institution's logo

routing_numbers: Option<Vec<String>>

A partial list of routing numbers associated with the institution. This list is provided for the purpose of looking up institutions by routing number. It is not comprehensive and should never be used as a complete list of routing numbers for an institution.

oauth: bool

Indicates that the institution has an OAuth login flow. This is primarily relevant to institutions with European country codes.