Struct plaid::institutions::Institution [−][src]
Fields
institution_id: StringUnique identifier for the institution
name: StringThe official name of the institution
products: Vec<String>A list of the Plaid products supported by the institution Possible values: assets, auth, balance, identity, investments, liabilities, payment_initiation, transactions, credit_details, income, deposit_switch
country_codes: Vec<String>A list of the country codes supported by the institution. Possible values: US, GB, ES, NL, FR, IE, CA
url: Option<String>The URL for the institution's website
primary_color: Option<String>Hexadecimal representation of the primary color used by the institution
logo: Option<String>Base64 encoded representation of the institution's logo
routing_numbers: Option<Vec<String>>A partial list of routing numbers associated with the institution. This list is provided for the purpose of looking up institutions by routing number. It is not comprehensive and should never be used as a complete list of routing numbers for an institution.
oauth: boolIndicates that the institution has an OAuth login flow. This is primarily relevant to institutions with European country codes.